==> ginkgo-hpc-docs-1.10.0-2-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/namespacegko_1_1accessor.js <==
var namespacegko_1_1accessor =
[
    [ "abs_operation", "structgko_1_1accessor_1_1abs__operation.html", null ],
    [ "abs_operaton", "structgko_1_1accessor_1_1abs__operaton.html", null ],
    [ "add", "structgko_1_1accessor_1_1add.html", null ],
    [ "bitwise_and", "structgko_1_1accessor_1_1bitwise__and.html", null ],
    [ "bitwise_not", "structgko_1_1accessor_1_1bitwise__not.html", null ],
    [ "bitwise_or", "structgko_1_1accessor_1_1bitwise__or.html", null ],
    [ "bitwise_xor", "structgko_1_1accessor_1_1bitwise__xor.html", null ],
    [ "conj_operation", "structgko_1_1accessor_1_1conj__operation.html", null ],
    [ "conj_operaton", "structgko_1_1accessor_1_1conj__operaton.html", null ],
    [ "div", "structgko_1_1accessor_1_1div.html", null ],
    [ "equal", "structgko_1_1accessor_1_1equal.html", null ],
    [ "greater", "structgko_1_1accessor_1_1greater.html", null ],
    [ "greater_or_equal", "structgko_1_1accessor_1_1greater__or__equal.html", null ],
    [ "imag_operation", "structgko_1_1accessor_1_1imag__operation.html", null ],
    [ "imag_operaton", "structgko_1_1accessor_1_1imag__operaton.html", null ],
    [ "left_shift", "structgko_1_1accessor_1_1left__shift.html", null ],
    [ "less", "structgko_1_1accessor_1_1less.html", null ],
    [ "less_or_equal", "structgko_1_1accessor_1_1less__or__equal.html", null ],
    [ "logical_and", "structgko_1_1accessor_1_1logical__and.html", null ],
    [ "logical_not", "structgko_1_1accessor_1_1logical__not.html", null ],
    [ "logical_or", "structgko_1_1accessor_1_1logical__or.html", null ],
    [ "max_operation", "structgko_1_1accessor_1_1max__operation.html", null ],
    [ "min_operation", "structgko_1_1accessor_1_1min__operation.html", null ],
    [ "mmul_operation", "structgko_1_1accessor_1_1mmul__operation.html", null ],
    [ "mod", "structgko_1_1accessor_1_1mod.html", null ],
    [ "mul", "structgko_1_1accessor_1_1mul.html", null ],
    [ "not_equal", "structgko_1_1accessor_1_1not__equal.html", null ],
    [ "one_operation", "structgko_1_1accessor_1_1one__operation.html", null ],
    [ "one_operaton", "structgko_1_1accessor_1_1one__operaton.html", null ],
    [ "real_operation", "structgko_1_1accessor_1_1real__operation.html", null ],
    [ "real_operaton", "structgko_1_1accessor_1_1real__operaton.html", null ],
    [ "right_shift", "structgko_1_1accessor_1_1right__shift.html", null ],
    [ "row_major", "classgko_1_1accessor_1_1row__major.html", "classgko_1_1accessor_1_1row__major" ],
    [ "squared_norm_operation", "structgko_1_1accessor_1_1squared__norm__operation.html", null ],
    [ "squared_norm_operaton", "structgko_1_1accessor_1_1squared__norm__operaton.html", null ],
    [ "sub", "structgko_1_1accessor_1_1sub.html", null ],
    [ "transpose_operation", "structgko_1_1accessor_1_1transpose__operation.html", null ],
    [ "unary_minus", "structgko_1_1accessor_1_1unary__minus.html", null ],
    [ "unary_plus", "structgko_1_1accessor_1_1unary__plus.html", null ],
    [ "zero_operation", "structgko_1_1accessor_1_1zero__operation.html", null ]
];

==> ginkgo-hpc-docs-1.11.0-2-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/namespacegko_1_1accessor.js <==
var namespacegko_1_1accessor =
[
    [ "unary_plus", "structgko_1_1accessor_1_1unary__plus.html", null ],
    [ "unary_minus", "structgko_1_1accessor_1_1unary__minus.html", null ],
    [ "logical_not", "structgko_1_1accessor_1_1logical__not.html", null ],
    [ "bitwise_not", "structgko_1_1accessor_1_1bitwise__not.html", null ],
    [ "zero_operation", "structgko_1_1accessor_1_1zero__operation.html", null ],
    [ "one_operation", "structgko_1_1accessor_1_1one__operation.html", null ],
    [ "abs_operation", "structgko_1_1accessor_1_1abs__operation.html", null ],
    [ "real_operation", "structgko_1_1accessor_1_1real__operation.html", null ],
    [ "imag_operation", "structgko_1_1accessor_1_1imag__operation.html", null ],
    [ "conj_operation", "structgko_1_1accessor_1_1conj__operation.html", null ],
    [ "squared_norm_operation", "structgko_1_1accessor_1_1squared__norm__operation.html", null ],
    [ "one_operaton", "structgko_1_1accessor_1_1one__operaton.html", null ],
    [ "abs_operaton", "structgko_1_1accessor_1_1abs__operaton.html", null ],
    [ "real_operaton", "structgko_1_1accessor_1_1real__operaton.html", null ],
    [ "imag_operaton", "structgko_1_1accessor_1_1imag__operaton.html", null ],
    [ "conj_operaton", "structgko_1_1accessor_1_1conj__operaton.html", null ],
    [ "squared_norm_operaton", "structgko_1_1accessor_1_1squared__norm__operaton.html", null ],
    [ "transpose_operation", "structgko_1_1accessor_1_1transpose__operation.html", null ],
    [ "add", "structgko_1_1accessor_1_1add.html", null ],
    [ "sub", "structgko_1_1accessor_1_1sub.html", null ],
    [ "mul", "structgko_1_1accessor_1_1mul.html", null ],
    [ "div", "structgko_1_1accessor_1_1div.html", null ],
    [ "mod", "structgko_1_1accessor_1_1mod.html", null ],
    [ "less", "structgko_1_1accessor_1_1less.html", null ],
    [ "greater", "structgko_1_1accessor_1_1greater.html", null ],
    [ "less_or_equal", "structgko_1_1accessor_1_1less__or__equal.html", null ],
    [ "greater_or_equal", "structgko_1_1accessor_1_1greater__or__equal.html", null ],
    [ "equal", "structgko_1_1accessor_1_1equal.html", null ],
    [ "not_equal", "structgko_1_1accessor_1_1not__equal.html", null ],
    [ "logical_or", "structgko_1_1accessor_1_1logical__or.html", null ],
    [ "logical_and", "structgko_1_1accessor_1_1logical__and.html", null ],
    [ "bitwise_or", "structgko_1_1accessor_1_1bitwise__or.html", null ],
    [ "bitwise_and", "structgko_1_1accessor_1_1bitwise__and.html", null ],
    [ "bitwise_xor", "structgko_1_1accessor_1_1bitwise__xor.html", null ],
    [ "left_shift", "structgko_1_1accessor_1_1left__shift.html", null ],
    [ "right_shift", "structgko_1_1accessor_1_1right__shift.html", null ],
    [ "max_operation", "structgko_1_1accessor_1_1max__operation.html", null ],
    [ "min_operation", "structgko_1_1accessor_1_1min__operation.html", null ],
    [ "mmul_operation", "structgko_1_1accessor_1_1mmul__operation.html", null ],
    [ "row_major", "classgko_1_1accessor_1_1row__major.html", "classgko_1_1accessor_1_1row__major" ]
];
